@@ -80,7 +80,7 @@ class Test_Open_FilePicker(object):
         QtWidgets.QApplication.processEvents()
         QtWidgets.QApplication.processEvents()
         self.window.action()
-        _file_names = [name.keys()[0] for name in self.window.file_list_items]
+        _file_names = [list(name)[0] for name in self.window.file_list_items]
         assert u"./foo/foo.txt" in _file_names
         assert len(self.window.file_list_items) == 1
 
@@ -92,7 +92,7 @@ class Test_Open_FilePicker(object):
     def test_showname_on_filename(self):
         self.window.show_name()
         filename = u"./example.csv"
-        _file_names = [name.keys()[0] for name in self.window.file_list_items]
+        _file_names = [list(name)[0] for name in self.window.file_list_items]
         all_items = self.window.dir_list_items + _file_names
         index = all_items.index(filename)
         self.window.ui_FileList.selectRow(index)
@@ -127,11 +127,11 @@ class Test_Open_FilePicker(object):
         assert self.window.filename == u"example.txt"
 
     def test_subdirectory(self):
-        _folder_names = [name.keys()[0] for name in self.window.dir_list_items]
+        _folder_names = [list(name)[0] for name in self.window.dir_list_items]
         index = _folder_names.index(u'./bar')
         self.window.onCellDoubleClicked(index, 0)
         QtWidgets.QApplication.processEvents()
-        _file_names = [name.keys()[0] for name in self.window.file_list_items]
+        _file_names = [list(name)[0] for name in self.window.file_list_items]
         assert _file_names[0] == "./bar/foo.txt"
         self.window.onCellClicked(0, 0)
         QtWidgets.QApplication.processEvents()
@@ -144,7 +144,7 @@ class Test_Open_FilePicker(object):
         self.window.onCellDoubleClicked(0, 0)
         QtWidgets.QApplication.processEvents()
         self.window.close()
-        _file_names = [name.keys()[0] for name in self.window.file_list_items]
+        _file_names = [list(name)[0] for name in self.window.file_list_items]
         assert u"bar" in self.window.ui_DirList.currentText()
         assert u"./bar/foo.txt" in _file_names
 
@@ -224,7 +224,7 @@ class Test_Save_FilePicker(object):
         self.window.action()
         QtWidgets.QApplication.processEvents()
         self.window.close()
-        assert self.window.wparm.value.keys()[0] == u"./empty"
+        assert list(self.window.wparm.value)[0] == u"./empty"
         assert u"example.txt" in self.window.filename
 
     @mock.patch("fslib.fs_filepicker.QtWidgets.QInputDialog.getText",
@@ -238,13 +238,13 @@ class Test_Save_FilePicker(object):
         self.window.make_dir()
         QtWidgets.QApplication.processEvents()
         self.window.close()
-        _folder_names = [name.keys()[0] for name in self.window.dir_list_items]
+        _folder_names = [list(name)[0] for name in self.window.dir_list_items]
         assert u'./empty/exampledir' in _folder_names
 
     @mock.patch("fslib.fs_filepicker.QtWidgets.QInputDialog.getText",
                 return_value=(u"thisexampledir", True))
     def test_history_makedir(self, mocktext):
-        _folder_names = [name.keys()[0] for name in self.window.dir_list_items]
+        _folder_names = [list(name)[0] for name in self.window.dir_list_items]
         index = _folder_names.index(u'./empty')
         self.window.onCellDoubleClicked(index, 0)
         QtWidgets.QApplication.processEvents()
@@ -257,7 +257,7 @@ class Test_Save_FilePicker(object):
         QtWidgets.QApplication.processEvents()
         self.window.make_dir()
         QtWidgets.QApplication.processEvents()
-        _folder_names = [name.keys()[0] for name in self.window.dir_list_items]
+        _folder_names = [list(name)[0] for name in self.window.dir_list_items]
         self.window.close()
         assert u'./empty/thisexampledir' in _folder_names
         assert self.window.last_dir_index == 1
